==> am_mod_blg_0_3.tar.gz: am_mod_blg_0_3/components/blg/inc/blg_item_select.function.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// this function is used to return a single row as an item array
// the core uses this to obtain a row and return it in a format it
// can understand

function selItemModule_blg($blog_id, $entry_id = null) {
	
	global $db;
	
	$item = array();
	
	if (isset($entry_id)) {
		$query = "
			SELECT blog_id, entry_id, page_title 
			FROM " . $db->prefix . "_library_page 
			WHERE 
			blog_id=" . $blog_id . " AND 
			entry_id=" . $entry_id
		;
			
		$result = $db->SelectLimit($query, 1);
	
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['page_title'];
			$item['item_url'] = "index.php?amn=lbr_page&amp;blog_id=" . $result->fields['blog_id'] . "&amp;entry_id=" . $result->fields['entry_id'];
			
			return $item;
		}
	}
	else {
		$query = "
			SELECT blog_id, set_title 
			FROM " . $db->prefix . "_library_set 
			WHERE 
			blog_id=" . $blog_id
		;
			
		$result = $db->SelectLimit($query, 1);
	
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['set_title'];
			$item['item_url'] = "index.php?amn=lbr_page&amp;blog_id=" . $result->fields['blog_id'];
			
			return $item;
		}
	}
}

?>

==> am_mod_blg_0_5.tar.gz: am_mod_blg_0_5/components/blg/inc/blg_item_select.function.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// this function is used to return a single row as an item array
// the core uses this to obtain a row and return it in a format it
// can understand

function selItemModule_blg($blog_id, $entry_id = null) {
	
	global $db;
	
	$item = array();
	
	if (isset($entry_id)) {
		$query = "
			SELECT blog_id, entry_id, entry_title
			FROM " . $db->prefix . "_blog_entry 
			WHERE 
			entry_id=" . $entry_id
		;
		
		$result = $db->SelectLimit($query, 1);
	
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['entry_title'];
			$item['item_url'] = "index.php?amn=blg_item&amp;blog_id=" . $result->fields['blog_id'] . "&amp;entry_id=" . $result->fields['entry_id'];
			
			return $item;
		}
	}
	else {
		$query = "
			SELECT blog_id, blog_title
			FROM " . $db->prefix . "_blog 
			WHERE 
			blog_id=" . $blog_id
		;
			
		$result = $db->SelectLimit($query, 1);
	
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['blog_title'];
			$item['item_url'] = "index.php?amn=blg_item&amp;blog_id=" . $result->fields['blog_id'];
			
			return $item;
		}
	}
}

?>
